from distutils.core import setup

setup(
	name="palindrome",
	version="1.0.0",
	py_modules=["palindrome"],
	author="Dhruba Karmakar",
	author_email="medhrk@gmail.com",
	url="http://www.bagsandwallet.weebly.com",
	description="A simple palindrome checker",
)
